% SIFTSdemo4
%
% DESCRIPTION:
%  Example of transformation estimation using the matchings between Local
%  Planar Descriptors of a parabolic omnidirectional image and SIFT
%  descriptors of a planar image
%
% VERSION:
%  1.1
%
% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

global SIFTSLocalPath;
% Parabolic image:
imageStr = [SIFTSLocalPath '/TestImages/Parabolic_Image.jpg'];

% Radius of the disk image (should depend on the sensor calibration)
R = 3.2;

% Spherical image size
sphSize = 1024;
 
% Compute spherical image
parabolicImage = imread(imageStr);
        sphImg = KAIDANToSphere_colour(parabolicImage, R, sphSize);

% Load planar image
disp('[SIFTS] Loading planar image...');
imageStrPlanar = [SIFTSLocalPath '/TestImages/Planar_Image.jpg'];
planarImg = imread(imageStrPlanar);
msg = sprintf('[SIFTS] Done!\n');
disp(msg);

% Load precomputed correspondences. This correspondences have been obtained by matching
% Local Planar Descriptors extracted from image "Parabolic_Image.jpg", and SIFT descriptors
% extracted from image "Planar_Image.jpg".
disp('[SIFTS] Loading precomputed correspondences...');
matchingDataStr = [SIFTSLocalPath '/DataFiles/planarVSspherical_Correspondences.mat'];
load(matchingDataStr);
msg = sprintf('[SIFTS] Done!\n');
disp(msg);

% Compute transformation
H = computeTransform(sphImg, planarImg, sphPoints, planarPoints);
