function [SDoG] = differenceOfGaussians(SSS)
% [SDoG] = differenceOfGaussians(SSS)
%
% DESCRIPTION:
%  Computes the spherical difference of Gaussians using the spherical
%  scale-space representation of an image
%
% VERSION:
%  1.1
%
% INPUT:
%  SSS  =  spherical scale-space representation of the 
%          image (output of "sphericalScaleSpace")
%
% OUTPUT:
%  SDoG  =  spherical difference of Gaussians
%
% SEE ALSO:    computeLSD

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    tic
    disp('[SIFTS] Computing difference of Gaussians scale space...');
    SDoG = struct(SSS);

    SDoG.numStagesPerOctave = SSS.numStagesPerOctave - 1;
    
    for i=1:SSS.numOctaves
        SDoG.octaves(i).octaveContents = repmat(struct(SSS.octaves(i).octaveContents(1)),[1 SDoG.numStagesPerOctave]);
        for j=1:SDoG.numStagesPerOctave
            SDoG.octaves(i).octaveContents(j).stage = SSS.octaves(i).octaveContents(j).stage;
            SDoG.octaves(i).octaveContents(j).sigma = SSS.octaves(i).octaveContents(j).sigma;
            SDoG.octaves(i).octaveContents(j).image = SSS.octaves(i).octaveContents(j+1).image - SSS.octaves(i).octaveContents(j).image;
        end
    end
    disp('[SIFTS] Done!');
    t=toc;
    disp(sprintf('[SIFTS] Computation time: %f seconds\n',t));
end
