function edge_response = checkEdge(r, H)
% edge_response = checkEdge(r, H)
%
% DESCRIPTION:
%  Checks whether the ratio between principal curvatures is smaller than a
%  fixed threshold
%
% VERSION:
%  1.1
%
% INPUT:
%  r  =  threshold of the ratio
%  H  =  Hessian matrix (in theta and phi coordinates)
%
% OUTPUT:
%  edge_response  =  1 if curvatures have the same sign and the ratio is 
%                    smaller than the threshold, 0 otherwise

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    edge_response = 0;
    % Compute trace and determinant
    tr = H(1,1) + H(2,2);
    det = H(1,1)*H(2,2) - H(1,2)*H(2,1);

    % check that curvatures don't have different signs and 
    % (trace^2)/det < ((r+1)^2)/r
    
    if( (det>0) && ((tr*tr)/det < ((r + 1)^2)/r ) )
        edge_response = 1;
    end
end
