function [x,y] = computeRegionIndex(phiValues, thetaValues, phi, theta, imgC)
% [x,y] = computeRegionIndex(phiValues, thetaValues, phi, theta, imgC)
%
% DESCRIPTION:
%  Computes indexes on the spherical grid of the points given as input
%  parameters
%
% VERSION:
%  1.1
%
% INPUT:
%  phiValues    =  matrix containing phi values of the points whose index
%                  in the spherical grid wants to be computed
%  thetaValues  =  matrix containing theta values of the points whose index
%                  in the spherical grid wants to be computed
%  phi          =  array of phi values of the spherical grid
%  theta        =  array of theta values of the spherical grid
%  imgC         =  number of columns of the spherical image
%
% OUTPUT:
%  x  =  column indexes on the spherical grid
%  y  =  row indexes on the spherical grid

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    [N,M] = size(phiValues);
    
    x = zeros(N,M);
    y = zeros(N,M);
    
    for i=1:M
        for j=1:N
            jumpValue = 0;
            if(phiValues(j,i)<0.0)
                jumpValue=1;
                phiValues(j,i) = phiValues(j,i) + 2*pi;
            elseif(phiValues(j,i)>=2*pi)
                jumpValue=2;
                phiValues(j,i) = phiValues(j,i) - 2*pi;
            end
            [val, x(j,i)] = min(abs(phiValues(j,i)-phi(:)));
            [val, y(j,i)] = min(abs(thetaValues(j,i)-theta(:)'));
            if(jumpValue==1)
                x(j,i) = x(j,i) - imgC;
            elseif(jumpValue==2)
                x(j,i) = x(j,i) + imgC;
            end
        end
    end
end
