function weight = gradientWeight(angleDistance,sigma,factor)
% weight = gradientWeight(angleDistance,sigma,factor)
%
% DESCRIPTION:
%  Computes weight for adding values to histograms of orientations
%
% VERSION:
%  1.1
%
% INPUT:
%  angleDistance  =  distance on the sphere
%  sigma          =  sigma corresponding to the detected point
%  factor         =  magnification factor
%
% OUTPUT:
%  weight  = output weight

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    % Calculate weight
    weight = exp(-(angleDistance^2)/(2*(factor*sigma)^2));
    
end
