function [contrast] = interpolateContrast(Img, r, c, z, dD)
% [contrast] = interpolateContrast(Img, r, c, z, dD)
%
% DESCRIPTION:
%  Interpolates the value of the contrast at the computed extreme
%
% VERSION:
%  1.1
%
% INPUT:
%  Img  =  grayscale value of the omnidirectional image mapped on the 
%          sphere at the position before maximum adjustment process
%  r    =  row in the spherical grid
%  c    =  column in the spherical grid
%  z    =  position in the scale dimension
%  dD   =  partial derivatives with respect to phi, theta and scale
%
% OUTPUT:
%  contrast  =  interpolated contrast value

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    contrast = Img + 0.5*dD'*[c;r;z];
end
