function dist = sphericalDistance(phiOrig, phi, thetaOrig, theta)
% dist = sphericalDistance(phiOrig, phi, thetaOrig, theta)
%
% DESCRIPTION:
%  Computes distance between two points on the sphere
%
% VERSION:
%  1.1
%
% INPUT:
%  phiOrig    =  phi value of the first point
%  phi        =  phi value of the second point (can be an array)
%  thetaOrig  =  theta value of the first point
%  theta      =  theta value of the second point (can be an array)
%
% OUTPUT:
%  dist  =  computed distance

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    sinTheta = sin(theta);
    sinThetaOrig = sin(thetaOrig);
    sinDeltaPhi = sin(phi-phiOrig);
    cosTheta = cos(theta);
    cosThetaOrig = cos(thetaOrig);
    cosDeltaPhi = cos(phi-phiOrig);
    dist = atan2(sqrt((sinTheta.*sinDeltaPhi).^2+(sinThetaOrig*cosTheta-cosThetaOrig*sinTheta.*cosDeltaPhi).^2), ...
                  cosThetaOrig*cosTheta+sinThetaOrig*sinTheta.*cosDeltaPhi);
end
